@@ -9,6 +9,7 @@ from copy import copy as ccopy
 from copy import deepcopy
 from datetime import datetime
 from html import escape
+import re
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -67,11 +68,11 @@ SUPPORTED_GROUPS = [
 WARMUP_TAG = "warmup_"
 
 SUPPORTED_GROUPS_WARMUP = [
-    "{}posterior".format(WARMUP_TAG),
-    "{}posterior_predictive".format(WARMUP_TAG),
-    "{}predictions".format(WARMUP_TAG),
-    "{}sample_stats".format(WARMUP_TAG),
-    "{}log_likelihood".format(WARMUP_TAG),
+    f"{WARMUP_TAG}posterior",
+    f"{WARMUP_TAG}posterior_predictive",
+    f"{WARMUP_TAG}predictions",
+    f"{WARMUP_TAG}sample_stats",
+    f"{WARMUP_TAG}log_likelihood",
 ]
 
 SUPPORTED_GROUPS_ALL = SUPPORTED_GROUPS + SUPPORTED_GROUPS_WARMUP
@@ -88,12 +89,16 @@ class InferenceData(Mapping[str, xr.Dataset]):
     """
 
     def __init__(
-        self, **kwargs: Union[xr.Dataset, List[xr.Dataset], Tuple[xr.Dataset, xr.Dataset]]
+        self,
+        attrs: Union[None, Mapping[Any, Any]] = None,
+        **kwargs: Union[xr.Dataset, List[xr.Dataset], Tuple[xr.Dataset, xr.Dataset]],
     ) -> None:
         """Initialize InferenceData object from keyword xarray datasets.
 
         Parameters
         ----------
+        attrs : dict
+            sets global attribute for InferenceData object.
         kwargs :
             Keyword arguments of xarray datasets
 
@@ -132,13 +137,14 @@ class InferenceData(Mapping[str, xr.Dataset]):
         """
         self._groups: List[str] = []
         self._groups_warmup: List[str] = []
+        self._attrs: Union[None, dict] = dict(attrs) if attrs is not None else None
         save_warmup = kwargs.pop("save_warmup", False)
         key_list = [key for key in SUPPORTED_GROUPS_ALL if key in kwargs]
         for key in kwargs:
             if key not in SUPPORTED_GROUPS_ALL:
                 key_list.append(key)
                 warnings.warn(
-                    "{} group is not defined in the InferenceData scheme".format(key), UserWarning
+                    f"{key} group is not defined in the InferenceData scheme", UserWarning
                 )
         for key in key_list:
             dataset = kwargs[key]
@@ -162,17 +168,28 @@ class InferenceData(Mapping[str, xr.Dataset]):
                     self._groups_warmup.append(key)
             if save_warmup and dataset_warmup is not None:
                 if dataset_warmup:
-                    key = "{}{}".format(WARMUP_TAG, key)
+                    key = f"{WARMUP_TAG}{key}"
                     setattr(self, key, dataset_warmup)
                     self._groups_warmup.append(key)
 
+    @property
+    def attrs(self) -> dict:
+        """Attributes of InferenceData object."""
+        if self._attrs is None:
+            self._attrs = {}
+        return self._attrs
+
+    @attrs.setter
+    def attrs(self, value) -> None:
+        self._attrs = dict(value)
+
     def __repr__(self) -> str:
         """Make string representation of InferenceData object."""
         msg = "Inference data with groups:\n\t> {options}".format(
             options="\n\t> ".join(self._groups)
         )
         if self._groups_warmup:
-            msg += "\n\nWarmup iterations saved ({}*).".format(WARMUP_TAG)
+            msg += f"\n\nWarmup iterations saved ({WARMUP_TAG}*)."
         return msg
 
     def _repr_html_(self) -> str:
@@ -200,7 +217,7 @@ class InferenceData(Mapping[str, xr.Dataset]):
                     HtmlTemplate.html_template.format(elements)
                 )
                 css_template = HtmlTemplate.css_template  # pylint: disable=possibly-unused-variable
-                html_repr = "%(formatted_html_template)s%(css_template)s" % locals()
+                html_repr = f"{locals()['formatted_html_template']}{locals()['css_template']}"
         except:  # pylint: disable=bare-except
             html_repr = f"<pre>{escape(repr(self))}</pre>"
         return html_repr
@@ -243,7 +260,9 @@ class InferenceData(Mapping[str, xr.Dataset]):
     class InferenceDataValuesView(ValuesView[xr.Dataset]):
         """ValuesView implementation for InferenceData, to allow it to implement Mapping."""
 
-        def __init__(self, parent: "InferenceData") -> None:
+        def __init__(  # pylint: disable=super-init-not-called
+            self, parent: "InferenceData"
+        ) -> None:
             """Create a new InferenceDataValuesView from an InferenceData object."""
             self.parent = parent
 
@@ -275,7 +294,9 @@ class InferenceData(Mapping[str, xr.Dataset]):
     class InferenceDataItemsView(ItemsView[str, xr.Dataset]):
         """ItemsView implementation for InferenceData, to allow it to implement Mapping."""
 
-        def __init__(self, parent: "InferenceData") -> None:
+        def __init__(  # pylint: disable=super-init-not-called
+            self, parent: "InferenceData"
+        ) -> None:
             """Create a new InferenceDataItemsView from an InferenceData object."""
             self.parent = parent
 
@@ -310,7 +331,7 @@ class InferenceData(Mapping[str, xr.Dataset]):
         return InferenceData.InferenceDataItemsView(self)
 
     @staticmethod
-    def from_netcdf(filename: str) -> "InferenceData":
+    def from_netcdf(filename, group_kwargs=None, regex=False) -> "InferenceData":
         """Initialize object from a netcdf file.
 
         Expects that the file will have groups, each of which can be loaded by xarray.
@@ -322,22 +343,54 @@ class InferenceData(Mapping[str, xr.Dataset]):
         ----------
         filename : str
             location of netcdf file
+        group_kwargs : dict of {str: dict}, optional
+            Keyword arguments to be passed into each call of :func:`xarray.open_dataset`.
+            The keys of the higher level should be group names or regex matching group
+            names, the inner dicts re passed to ``open_dataset``
+            This feature is currently experimental.
+        regex : bool, default False
+            Specifies where regex search should be used to extend the keyword arguments.
+            This feature is currently experimental.
 
         Returns
         -------
         InferenceData object
         """
         groups = {}
-        with nc.Dataset(filename, mode="r") as data:
-            data_groups = list(data.groups)
 
-        for group in data_groups:
-            with xr.open_dataset(filename, group=group) as data:
-                if rcParams["data.load"] == "eager":
-                    groups[group] = data.load()
-                else:
-                    groups[group] = data
-        return InferenceData(**groups)
+        try:
+            with nc.Dataset(filename, mode="r") as data:
+                data_groups = list(data.groups)
+
+            for group in data_groups:
+
+                group_kws = {}
+                if group_kwargs is not None and regex is False:
+                    group_kws = group_kwargs.get(group, {})
+                if group_kwargs is not None and regex is True:
+                    for key, kws in group_kwargs.items():
+                        if re.search(key, group):
+                            group_kws = kws
+                with xr.open_dataset(filename, group=group, **group_kws) as data:
+                    if rcParams["data.load"] == "eager":
+                        groups[group] = data.load()
+                    else:
+                        groups[group] = data
+            res = InferenceData(**groups)
+            return res
+        except OSError as e:  # pylint: disable=invalid-name
+            if e.errno == -101:
+                raise type(e)(
+                    str(e)
+                    + (
+                        " while reading a NetCDF file. This is probably an error in HDF5, "
+                        "which happens because your OS does not support HDF5 file locking.  See "
+                        "https://stackoverflow.com/questions/49317927/"
+                        "errno-101-netcdf-hdf-error-when-opening-netcdf-file#49317928"
+                        " for a possible solution."
+                    )
+                )
+            raise e
 
     def to_netcdf(
         self, filename: str, compress: bool = True, groups: Optional[List[str]] = None
@@ -400,7 +453,6 @@ class InferenceData(Mapping[str, xr.Dataset]):
             When `data=False` return just the schema.
         """
         ret = defaultdict(dict)
-        attrs = None
         if self._groups_all:  # check's whether a group is present or not.
             if groups is None:
                 groups = self._group_names(groups, filter_groups)
@@ -430,15 +482,9 @@ class InferenceData(Mapping[str, xr.Dataset]):
                     if len(dims) > 0:
                         ret[dims_key][var_name] = dims
                     ret[group] = data
-                if attrs is None:
-                    attrs = dataset.attrs
-                elif attrs != dataset.attrs:
-                    warnings.warn(
-                        "The attributes are not same for all groups."
-                        " Considering only the first group `attrs`"
-                    )
+                ret[group + "_attrs"] = dataset.attrs
 
-        ret["attrs"] = attrs
+        ret["attrs"] = self.attrs
         return ret
 
     def to_json(self, filename, groups=None, filter_groups=None, **kwargs):
@@ -468,7 +514,7 @@ class InferenceData(Mapping[str, xr.Dataset]):
             self.to_dict(groups=groups, filter_groups=filter_groups)
         )
 
-        with open(filename, "w") as file:
+        with open(filename, "w", encoding="utf8") as file:
             json.dump(idata_dict, file, **kwargs)
 
         return filename
@@ -522,14 +568,14 @@ class InferenceData(Mapping[str, xr.Dataset]):
         if index_origin is None:
             index_origin = rcParams["data.index_origin"]
         if index_origin not in [0, 1]:
-            raise TypeError("index_origin must be 0 or 1, saw {}".format(index_origin))
+            raise TypeError(f"index_origin must be 0 or 1, saw {index_origin}")
 
         group_names = list(
             filter(lambda x: "data" not in x, self._group_names(groups, filter_groups))
         )
 
         if not group_names:
-            raise TypeError("No valid groups found: {}".format(groups))
+            raise TypeError(f"No valid groups found: {groups}")
 
         dfs = {}
         for group in group_names:
@@ -556,12 +602,10 @@ class InferenceData(Mapping[str, xr.Dataset]):
                                 idxs.append(coords_to_idx[coordname][coorditem])
                             if include_coords:
                                 tuple_columns.append(
-                                    ("{}[{}]".format(name, ",".join(map(str, idxs))), *coords)
+                                    (f"{name}[{','.join(map(str, idxs))}]", *coords)
                                 )
                             else:
-                                tuple_columns.append(
-                                    "{}[{}]".format(name, ",".join(map(str, idxs)))
-                                )
+                                tuple_columns.append(f"{name}[{','.join(map(str, idxs))}]")
                         else:
                             tuple_columns.append((name, *coords))
 
@@ -1311,11 +1355,11 @@ class InferenceData(Mapping[str, xr.Dataset]):
             raise ValueError("One of group_dict or kwargs must be provided.")
         repeated_groups = [group for group in group_dict.keys() if group in self._groups]
         if repeated_groups:
-            raise ValueError("{} group(s) already exists.".format(repeated_groups))
+            raise ValueError(f"{repeated_groups} group(s) already exists.")
         for group, dataset in group_dict.items():
             if group not in SUPPORTED_GROUPS_ALL:
                 warnings.warn(
-                    "The group {} is not defined in the InferenceData scheme".format(group),
+                    f"The group {group} is not defined in the InferenceData scheme",
                     UserWarning,
                 )
             if dataset is None:
@@ -1344,9 +1388,29 @@ class InferenceData(Mapping[str, xr.Dataset]):
             if dataset:
                 setattr(self, group, dataset)
                 if group.startswith(WARMUP_TAG):
-                    self._groups_warmup.append(group)
+                    supported_order = [
+                        key for key in SUPPORTED_GROUPS_ALL if key in self._groups_warmup
+                    ]
+                    if (supported_order == self._groups_warmup) and (group in SUPPORTED_GROUPS_ALL):
+                        group_order = [
+                            key
+                            for key in SUPPORTED_GROUPS_ALL
+                            if key in self._groups_warmup + [group]
+                        ]
+                        group_idx = group_order.index(group)
+                        self._groups_warmup.insert(group_idx, group)
+                    else:
+                        self._groups_warmup.append(group)
                 else:
-                    self._groups.append(group)
+                    supported_order = [key for key in SUPPORTED_GROUPS_ALL if key in self._groups]
+                    if (supported_order == self._groups) and (group in SUPPORTED_GROUPS_ALL):
+                        group_order = [
+                            key for key in SUPPORTED_GROUPS_ALL if key in self._groups + [group]
+                        ]
+                        group_idx = group_order.index(group)
+                        self._groups.insert(group_idx, group)
+                    else:
+                        self._groups.append(group)
 
     def extend(self, other, join="left"):
         """Extend InferenceData with groups from another InferenceData.
@@ -1369,21 +1433,43 @@ class InferenceData(Mapping[str, xr.Dataset]):
         if not isinstance(other, InferenceData):
             raise ValueError("Extending is possible between two InferenceData objects only.")
         if join not in ("left", "right"):
-            raise ValueError("join must be either 'left' or 'right', found {}".format(join))
+            raise ValueError(f"join must be either 'left' or 'right', found {join}")
         for group in other._groups_all:  # pylint: disable=protected-access
             if hasattr(self, group):
                 if join == "left":
                     continue
             if group not in SUPPORTED_GROUPS_ALL:
                 warnings.warn(
-                    "{} group is not defined in the InferenceData scheme".format(group), UserWarning
+                    f"{group} group is not defined in the InferenceData scheme", UserWarning
                 )
             dataset = getattr(other, group)
             setattr(self, group, dataset)
             if group.startswith(WARMUP_TAG):
-                self._groups_warmup.append(group)
+                if group not in self._groups_warmup:
+                    supported_order = [
+                        key for key in SUPPORTED_GROUPS_ALL if key in self._groups_warmup
+                    ]
+                    if (supported_order == self._groups_warmup) and (group in SUPPORTED_GROUPS_ALL):
+                        group_order = [
+                            key
+                            for key in SUPPORTED_GROUPS_ALL
+                            if key in self._groups_warmup + [group]
+                        ]
+                        group_idx = group_order.index(group)
+                        self._groups_warmup.insert(group_idx, group)
+                    else:
+                        self._groups_warmup.append(group)
             else:
-                self._groups.append(group)
+                if group not in self._groups:
+                    supported_order = [key for key in SUPPORTED_GROUPS_ALL if key in self._groups]
+                    if (supported_order == self._groups) and (group in SUPPORTED_GROUPS_ALL):
+                        group_order = [
+                            key for key in SUPPORTED_GROUPS_ALL if key in self._groups + [group]
+                        ]
+                        group_idx = group_order.index(group)
+                        self._groups.insert(group_idx, group)
+                    else:
+                        self._groups.append(group)
 
     set_index = _extend_xr_method(xr.Dataset.set_index, see_also="reset_index")
     get_index = _extend_xr_method(xr.Dataset.get_index)
@@ -1432,6 +1518,11 @@ class InferenceData(Mapping[str, xr.Dataset]):
         -------
         groups: list
         """
+        if filter_groups not in {None, "like", "regex"}:
+            raise ValueError(
+                f"'filter_groups' can only be None, 'like', or 'regex', got: '{filter_groups}'"
+            )
+
         all_groups = self._groups_all
         if groups is None:
             return all_groups
@@ -1627,7 +1718,6 @@ def concat(
     inplace: "Literal[True]",
     reset_dim: bool = True,
 ) -> None:
-    """Overload definition, see below for docstring."""
     ...
 
 
@@ -1639,7 +1729,6 @@ def concat(
     inplace: "Literal[False]",
     reset_dim: bool = True,
 ) -> InferenceData:
-    """Overload definition, see below for docstring."""
     ...
 
 
@@ -1652,7 +1741,6 @@ def concat(
     inplace: "Literal[False]",
     reset_dim: bool = True,
 ) -> InferenceData:
-    """Overload definition, see below for docstring."""
     ...
 
 
@@ -1665,7 +1753,6 @@ def concat(
     inplace: "Literal[True]",
     reset_dim: bool = True,
 ) -> None:
-    """Overload definition, see below for docstring."""
     ...
 
 
@@ -1678,7 +1765,6 @@ def concat(
     inplace: bool = False,
     reset_dim: bool = True,
 ) -> Optional[InferenceData]:
-    """Overload definition, see below for docstring."""
     ...
 
 
@@ -1783,7 +1869,7 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
             )
 
     if dim is not None and dim.lower() not in {"group", "chain", "draw"}:
-        msg = "Invalid `dim`: {}. Valid `dim` are {}".format(dim, '{"group", "chain", "draw"}')
+        msg = f'Invalid `dim`: {dim}. Valid `dim` are {{"group", "chain", "draw"}}'
         raise TypeError(msg)
     dim = dim.lower() if dim is not None else dim
 
@@ -1797,6 +1883,21 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
                 return args[0]
 
     current_time = str(datetime.now())
+    combined_attr = defaultdict(list)
+    for idata in args:
+        for key, val in idata.attrs.items():
+            combined_attr[key].append(val)
+
+    for key, val in combined_attr.items():
+        all_same = True
+        for indx in range(len(val) - 1):
+            if val[indx] != val[indx + 1]:
+                all_same = False
+                break
+        if all_same:
+            combined_attr[key] = val[0]
+    if inplace:
+        setattr(args[0], "_attrs", dict(combined_attr))
 
     if not inplace:
         # Keep order for python 3.5
@@ -1805,7 +1906,7 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
     if dim is None:
         arg0 = args[0]
         arg0_groups = ccopy(arg0._groups_all)
-        args_groups = dict()
+        args_groups = {}
         # check if groups are independent
         # Concat over unique groups
         for arg in args[1:]:
@@ -1865,7 +1966,7 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
                     msg = "Mismatch between the groups."
                     raise TypeError(msg)
             for group in arg._groups_all:
-                # handle data groups seperately
+                # handle data groups separately
                 if group not in ["observed_data", "constant_data", "predictions_constant_data"]:
                     # assert that groups are equal
                     if group not in arg0_groups:
@@ -1891,14 +1992,14 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
                         if var not in group0_vars:
                             msg = "Mismatch between the variables."
                             raise TypeError(msg)
-                        var_dims = getattr(group_data, var).dims
-                        var0_dims = getattr(group0_data, var).dims
+                        var_dims = group_data[var].dims
+                        var0_dims = group0_data[var].dims
                         if var_dims != var0_dims:
                             msg = "Mismatch between the dimensions."
                             raise TypeError(msg)
 
                         if dim not in var_dims or dim not in var0_dims:
-                            msg = "Dimension {} missing.".format(dim)
+                            msg = f"Dimension {dim} missing."
                             raise TypeError(msg)
 
                     # xr.concat
@@ -1915,7 +2016,7 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
                     if hasattr(group_data, "attrs"):
                         group_attrs = getattr(group_data, "attrs")
                     else:
-                        group_attrs = dict()
+                        group_attrs = {}
 
                     # gather attrs results to group0_attrs
                     for attr_key, attr_values in group_attrs.items():
@@ -1944,7 +2045,7 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
                             group0_attrs["previous_created_at"].append(attr_values)
 
                         elif attr_key in group0_attrs:
-                            combined_key = "combined_{}".format(attr_key)
+                            combined_key = f"combined_{attr_key}"
                             if combined_key not in group0_attrs:
                                 group0_attrs[combined_key] = [group0_attr_values]
                             group0_attrs[combined_key].append(attr_values)
@@ -1975,11 +2076,11 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
 
                     for var in group_vars:
                         if var not in group0_vars:
-                            var_data = getattr(group_data, var)
+                            var_data = group_data[var]
                             getattr(arg0, group)[var] = var_data
                         else:
-                            var_data = getattr(group_data, var)
-                            var0_data = getattr(group0_data, var)
+                            var_data = group_data[var]
+                            var0_data = group0_data[var]
                             if dim in var_data.dims and dim in var0_data.dims:
                                 concatenated_var = xr.concat((group_data, group0_data), dim=dim)
                                 group0_data[var] = concatenated_var
@@ -1993,7 +2094,7 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
                     if hasattr(group_data, "attrs"):
                         group_attrs = getattr(group_data, "attrs")
                     else:
-                        group_attrs = dict()
+                        group_attrs = {}
 
                     # gather attrs results to group0_attrs
                     for attr_key, attr_values in group_attrs.items():
@@ -2022,7 +2123,7 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
                             group0_attrs["previous_created_at"].append(attr_values)
 
                         elif attr_key in group0_attrs:
-                            combined_key = "combined_{}".format(attr_key)
+                            combined_key = f"combined_{attr_key}"
                             if combined_key not in group0_attrs:
                                 group0_attrs[combined_key] = [group0_attr_values]
                             group0_attrs[combined_key].append(attr_values)
@@ -2037,4 +2138,7 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
                     else:
                         inference_data_dict[group] = group0_data
 
+    if not inplace:
+        inference_data_dict["attrs"] = combined_attr
+
     return None if inplace else InferenceData(**inference_data_dict)
