@@ -648,13 +648,10 @@ def _unpack_fit(fit, items, save_warmup, dtypes):
     for item in items:
         if item in stan_vars_cols:
             col_idxs = stan_vars_cols[item]
-            if len(col_idxs) == 1:
-                raw_draws = draws[..., col_idxs[0]]
-            else:
-                raw_draws = fit.stan_variable(item, inc_warmup=save_warmup)
-                raw_draws = np.swapaxes(
-                    raw_draws.reshape((-1, nchains, *raw_draws.shape[1:]), order="F"), 0, 1
-                )
+            raw_draws = fit.stan_variable(item, inc_warmup=save_warmup)
+            raw_draws = np.swapaxes(
+                raw_draws.reshape((-1, nchains, *raw_draws.shape[1:]), order="F"), 0, 1
+            )
         elif item in sampler_vars_cols:
             col_idxs = sampler_vars_cols[item]
             raw_draws = draws[..., col_idxs[0]]
