@@ -1,11 +1,9 @@
 """Dictionary specific conversion code."""
 import warnings
+from typing import Optional
 
-import xarray as xr
-
-from .. import utils
 from ..rcparams import rcParams
-from .base import dict_to_dataset, generate_dims_coords, make_attrs, requires
+from .base import dict_to_dataset, requires
 from .inference_data import WARMUP_TAG, InferenceData
 
 
@@ -33,11 +31,13 @@ class DictConverter:
         warmup_log_likelihood=None,
         warmup_sample_stats=None,
         save_warmup=None,
+        index_origin=None,
         coords=None,
         dims=None,
         pred_dims=None,
         pred_coords=None,
         attrs=None,
+        **kwargs,
     ):
         self.posterior = posterior
         self.posterior_predictive = posterior_predictive
@@ -63,11 +63,14 @@ class DictConverter:
             if coords is None
             else {**coords, **pred_coords}
         )
+        self.index_origin = index_origin
+        self.coords = coords
         self.dims = dims
         self.pred_dims = dims if pred_dims is None else pred_dims
         self.attrs = {} if attrs is None else attrs
         self.attrs.pop("created_at", None)
         self.attrs.pop("arviz_version", None)
+        self._kwargs = kwargs
 
     def _init_dict(self, attr_name):
         dict_or_none = getattr(self, attr_name, {})
@@ -89,13 +92,24 @@ class DictConverter:
                 " For stats functions log likelihood data needs to be in log_likelihood group.",
                 UserWarning,
             )
-
+        posterior_attrs = self._kwargs.get("posterior_attrs")
+        posterior_warmup_attrs = self._kwargs.get("posterior_warmup_attrs")
         return (
             dict_to_dataset(
-                data, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+                data,
+                library=None,
+                coords=self.coords,
+                dims=self.dims,
+                attrs=posterior_attrs,
+                index_origin=self.index_origin,
             ),
             dict_to_dataset(
-                data_warmup, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+                data_warmup,
+                library=None,
+                coords=self.coords,
+                dims=self.dims,
+                attrs=posterior_warmup_attrs,
+                index_origin=self.index_origin,
             ),
         )
 
@@ -116,13 +130,24 @@ class DictConverter:
                 "favour of storing them in the log_likelihood group.",
                 PendingDeprecationWarning,
             )
-
+        sample_stats_attrs = self._kwargs.get("sample_stats_attrs")
+        sample_stats_warmup_attrs = self._kwargs.get("sample_stats_warmup_attrs")
         return (
             dict_to_dataset(
-                data, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+                data,
+                library=None,
+                coords=self.coords,
+                dims=self.dims,
+                attrs=sample_stats_attrs,
+                index_origin=self.index_origin,
             ),
             dict_to_dataset(
-                data_warmup, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+                data_warmup,
+                library=None,
+                coords=self.coords,
+                dims=self.dims,
+                attrs=sample_stats_warmup_attrs,
+                index_origin=self.index_origin,
             ),
         )
 
@@ -135,14 +160,16 @@ class DictConverter:
             raise TypeError("DictConverter.log_likelihood is not a dictionary")
         if not isinstance(data_warmup, dict):
             raise TypeError("DictConverter.warmup_log_likelihood is not a dictionary")
-
+        log_likelihood_attrs = self._kwargs.get("log_likelihood_attrs")
+        log_likelihood_warmup_attrs = self._kwargs.get("log_likelihood_warmup_attrs")
         return (
             dict_to_dataset(
                 data,
                 library=None,
                 coords=self.coords,
                 dims=self.dims,
-                attrs=self.attrs,
+                attrs=log_likelihood_attrs,
+                index_origin=self.index_origin,
                 skip_event_dims=True,
             ),
             dict_to_dataset(
@@ -150,7 +177,8 @@ class DictConverter:
                 library=None,
                 coords=self.coords,
                 dims=self.dims,
-                attrs=self.attrs,
+                attrs=log_likelihood_warmup_attrs,
+                index_origin=self.index_origin,
                 skip_event_dims=True,
             ),
         )
@@ -164,13 +192,24 @@ class DictConverter:
             raise TypeError("DictConverter.posterior_predictive is not a dictionary")
         if not isinstance(data_warmup, dict):
             raise TypeError("DictConverter.warmup_posterior_predictive is not a dictionary")
-
+        posterior_predictive_attrs = self._kwargs.get("posterior_predictive_attrs")
+        posterior_predictive_warmup_attrs = self._kwargs.get("posterior_predictive_warmup_attrs")
         return (
             dict_to_dataset(
-                data, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+                data,
+                library=None,
+                coords=self.coords,
+                dims=self.dims,
+                attrs=posterior_predictive_attrs,
+                index_origin=self.index_origin,
             ),
             dict_to_dataset(
-                data_warmup, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+                data_warmup,
+                library=None,
+                coords=self.coords,
+                dims=self.dims,
+                attrs=posterior_predictive_warmup_attrs,
+                index_origin=self.index_origin,
             ),
         )
 
@@ -183,13 +222,24 @@ class DictConverter:
             raise TypeError("DictConverter.predictions is not a dictionary")
         if not isinstance(data_warmup, dict):
             raise TypeError("DictConverter.warmup_predictions is not a dictionary")
-
+        predictions_attrs = self._kwargs.get("predictions_attrs")
+        predictions_warmup_attrs = self._kwargs.get("predictions_warmup_attrs")
         return (
             dict_to_dataset(
-                data, library=None, coords=self.coords, dims=self.pred_dims, attrs=self.attrs
+                data,
+                library=None,
+                coords=self.coords,
+                dims=self.pred_dims,
+                attrs=predictions_attrs,
+                index_origin=self.index_origin,
             ),
             dict_to_dataset(
-                data_warmup, library=None, coords=self.coords, dims=self.pred_dims, attrs=self.attrs
+                data_warmup,
+                library=None,
+                coords=self.coords,
+                dims=self.pred_dims,
+                attrs=predictions_warmup_attrs,
+                index_origin=self.index_origin,
             ),
         )
 
@@ -199,9 +249,14 @@ class DictConverter:
         data = self.prior
         if not isinstance(data, dict):
             raise TypeError("DictConverter.prior is not a dictionary")
-
+        prior_attrs = self._kwargs.get("prior_attrs")
         return dict_to_dataset(
-            data, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+            data,
+            library=None,
+            coords=self.coords,
+            dims=self.dims,
+            attrs=prior_attrs,
+            index_origin=self.index_origin,
         )
 
     @requires("sample_stats_prior")
@@ -210,9 +265,14 @@ class DictConverter:
         data = self.sample_stats_prior
         if not isinstance(data, dict):
             raise TypeError("DictConverter.sample_stats_prior is not a dictionary")
-
+        sample_stats_prior_attrs = self._kwargs.get("sample_stats_prior_attrs")
         return dict_to_dataset(
-            data, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+            data,
+            library=None,
+            coords=self.coords,
+            dims=self.dims,
+            attrs=sample_stats_prior_attrs,
+            index_origin=self.index_origin,
         )
 
     @requires("prior_predictive")
@@ -221,27 +281,31 @@ class DictConverter:
         data = self.prior_predictive
         if not isinstance(data, dict):
             raise TypeError("DictConverter.prior_predictive is not a dictionary")
-
+        prior_predictive_attrs = self._kwargs.get("prior_predictive_attrs")
         return dict_to_dataset(
-            data, library=None, coords=self.coords, dims=self.dims, attrs=self.attrs
+            data,
+            library=None,
+            coords=self.coords,
+            dims=self.dims,
+            attrs=prior_predictive_attrs,
+            index_origin=self.index_origin,
         )
 
-    def data_to_xarray(self, dct, group, dims=None):
+    def data_to_xarray(self, data, group, dims=None):
         """Convert data to xarray."""
-        data = dct
         if not isinstance(data, dict):
-            raise TypeError("DictConverter.{} is not a dictionary".format(group))
+            raise TypeError(f"DictConverter.{group} is not a dictionary")
         if dims is None:
             dims = {} if self.dims is None else self.dims
-        new_data = dict()
-        for key, vals in data.items():
-            vals = utils.one_de(vals)
-            val_dims = dims.get(key)
-            val_dims, coords = generate_dims_coords(
-                vals.shape, key, dims=val_dims, coords=self.coords
-            )
-            new_data[key] = xr.DataArray(vals, dims=val_dims, coords=coords)
-        return xr.Dataset(data_vars=new_data, attrs=make_attrs(attrs=self.attrs, library=None))
+        return dict_to_dataset(
+            data,
+            library=None,
+            coords=self.coords,
+            dims=self.dims,
+            default_dims=[],
+            attrs=self.attrs,
+            index_origin=self.index_origin,
+        )
 
     @requires("observed_data")
     def observed_data_to_xarray(self):
@@ -280,6 +344,7 @@ class DictConverter:
                 "constant_data": self.constant_data_to_xarray(),
                 "predictions_constant_data": self.predictions_constant_data_to_xarray(),
                 "save_warmup": self.save_warmup,
+                "attrs": self.attrs,
             }
         )
 
@@ -304,11 +369,13 @@ def from_dict(
     warmup_log_likelihood=None,
     warmup_sample_stats=None,
     save_warmup=None,
+    index_origin: Optional[int] = None,
     coords=None,
     dims=None,
     pred_dims=None,
     pred_coords=None,
     attrs=None,
+    **kwargs,
 ):
     """Convert Dictionary data into an InferenceData object.
 
@@ -336,6 +403,7 @@ def from_dict(
     save_warmup : bool
         Save warmup iterations InferenceData object. If not defined, use default
         defined by the rcParams.
+    index_origin : int, optional
     coords : dict[str, iterable]
         A dictionary containing the values that are used as index. The key
         is the name of the dimension, the values are the index values.
@@ -347,6 +415,18 @@ def from_dict(
         A mapping from variables to a list of coordinate values for predictions.
     attrs : dict
         A dictionary containing attributes for different groups.
+    kwargs : dict
+        A dictionary containing group attrs.
+        Accepted kwargs are:
+        - posterior_attrs, posterior_warmup_attrs : attrs for posterior group
+        - sample_stats_attrs, sample_stats_warmup_attrs : attrs for sample_stats group
+        - log_likelihood_attrs, log_likelihood_warmup_attrs : attrs for log_likelihood group
+        - posterior_predictive_attrs, posterior_predictive_warmup_attrs : attrs for
+                posterior_predictive group
+        - predictions_attrs, predictions_warmup_attrs : attrs for predictions group
+        - prior_attrs : attrs for prior group
+        - sample_stats_prior_attrs : attrs for sample_stats_prior group
+        - prior_predictive_attrs : attrs for prior_predictive group
 
     Returns
     -------
@@ -370,9 +450,11 @@ def from_dict(
         warmup_log_likelihood=warmup_log_likelihood,
         warmup_sample_stats=warmup_sample_stats,
         save_warmup=save_warmup,
+        index_origin=index_origin,
         coords=coords,
         dims=dims,
         pred_dims=pred_dims,
         pred_coords=pred_coords,
         attrs=attrs,
+        **kwargs,
     ).to_inference_data()
