@@ -1,15 +1,15 @@
 """Matplotlib pairplot."""
 import warnings
+from copy import deepcopy
 
 import matplotlib.pyplot as plt
 import numpy as np
-from matplotlib.ticker import NullFormatter
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 
 from ....rcparams import rcParams
 from ...distplot import plot_dist
 from ...kdeplot import plot_kde
-from ...plot_utils import _scale_fig_size, calculate_point_estimate
+from ...plot_utils import _scale_fig_size, calculate_point_estimate, _init_kwargs_dict
 from . import backend_kwarg_defaults, backend_show, matplotlib_kwarg_dealiaser
 
 
@@ -40,14 +40,11 @@ def plot_pair(
     reference_values_kwargs,
 ):
     """Matplotlib pairplot."""
-    if backend_kwargs is None:
-        backend_kwargs = {}
-
+    backend_kwargs = _init_kwargs_dict(backend_kwargs)
     backend_kwargs = {
         **backend_kwarg_defaults(),
         **backend_kwargs,
     }
-    backend_kwargs.pop("constrained_layout")
 
     scatter_kwargs = matplotlib_kwarg_dealiaser(scatter_kwargs, "scatter")
 
@@ -56,11 +53,9 @@ def plot_pair(
     # Sets the default zorder higher than zorder of grid, which is 0.5
     scatter_kwargs.setdefault("zorder", 0.6)
 
-    if kde_kwargs is None:
-        kde_kwargs = {}
+    kde_kwargs = _init_kwargs_dict(kde_kwargs)
 
-    if hexbin_kwargs is None:
-        hexbin_kwargs = {}
+    hexbin_kwargs = matplotlib_kwarg_dealiaser(hexbin_kwargs, "hexbin")
     hexbin_kwargs.setdefault("mincnt", 1)
 
     divergences_kwargs = matplotlib_kwarg_dealiaser(divergences_kwargs, "plot")
@@ -69,8 +64,7 @@ def plot_pair(
     divergences_kwargs.setdefault("color", "C1")
     divergences_kwargs.setdefault("lw", 0)
 
-    if marginal_kwargs is None:
-        marginal_kwargs = {}
+    marginal_kwargs = _init_kwargs_dict(marginal_kwargs)
 
     point_estimate_kwargs = matplotlib_kwarg_dealiaser(point_estimate_kwargs, "fill_between")
     point_estimate_kwargs.setdefault("color", "k")
@@ -220,15 +214,15 @@ def plot_pair(
                 reference_values_copy[flat_var_names[1]],
                 **reference_values_kwargs,
             )
-        ax.set_xlabel("{}".format(flat_var_names[0]), fontsize=ax_labelsize, wrap=True)
-        ax.set_ylabel("{}".format(flat_var_names[1]), fontsize=ax_labelsize, wrap=True)
+        ax.set_xlabel(f"{flat_var_names[0]}", fontsize=ax_labelsize, wrap=True)
+        ax.set_ylabel(f"{flat_var_names[1]}", fontsize=ax_labelsize, wrap=True)
         ax.tick_params(labelsize=xt_labelsize)
 
     else:
         not_marginals = int(not marginals)
         num_subplot_cols = numvars - not_marginals
         max_plots = (
-            num_subplot_cols ** 2
+            num_subplot_cols**2
             if rcParams["plot.max_subplots"] is None
             else rcParams["plot.max_subplots"]
         )
@@ -251,11 +245,29 @@ def plot_pair(
         point_estimate_marker_kwargs.setdefault("s", markersize + 50)
 
         if ax is None:
+            if backend_kwargs.pop("sharex", None) is not None:
+                warnings.warn(
+                    "'sharex' keyword is ignored. For non-standard sharing, provide 'ax'.",
+                    UserWarning,
+                )
+            if backend_kwargs.pop("sharey", None) is not None:
+                warnings.warn(
+                    "'sharey' keyword is ignored. For non-standard sharing, provide 'ax'.",
+                    UserWarning,
+                )
+            backend_kwargs["sharex"] = "col"
+            if not_marginals:
+                backend_kwargs["sharey"] = "row"
             fig, ax = plt.subplots(
                 vars_to_plot,
                 vars_to_plot,
                 **backend_kwargs,
             )
+            if backend_kwargs.get("sharey") is None:
+                for j in range(0, vars_to_plot):
+                    for i in range(0, j):
+                        ax[j, i].axes.sharey(ax[j, 0])
+
         hexbin_values = []
         for i in range(0, vars_to_plot):
             var1 = plotters[i][-1].flatten()
@@ -284,7 +296,7 @@ def plot_pair(
                             var1,
                             var2,
                             ax=ax[j, i],
-                            **kde_kwargs,
+                            **deepcopy(kde_kwargs),
                         )
 
                     if "hexbin" in kind:
@@ -330,16 +342,14 @@ def plot_pair(
                             )
 
                 if j != vars_to_plot - 1:
-                    ax[j, i].axes.get_xaxis().set_major_formatter(NullFormatter())
+                    plt.setp(ax[j, i].get_xticklabels(), visible=False)
                 else:
-                    ax[j, i].set_xlabel(
-                        "{}".format(flat_var_names[i]), fontsize=ax_labelsize, wrap=True
-                    )
+                    ax[j, i].set_xlabel(f"{flat_var_names[i]}", fontsize=ax_labelsize, wrap=True)
                 if i != 0:
-                    ax[j, i].axes.get_yaxis().set_major_formatter(NullFormatter())
+                    plt.setp(ax[j, i].get_yticklabels(), visible=False)
                 else:
                     ax[j, i].set_ylabel(
-                        "{}".format(flat_var_names[j + not_marginals]),
+                        f"{flat_var_names[j + not_marginals]}",
                         fontsize=ax_labelsize,
                         wrap=True,
                     )
