@@ -38,7 +38,7 @@ def plot_hdi(
         Values to plot.
     y : array-like, optional
         Values from which to compute the HDI. Assumed shape ``(chain, draw, \*shape)``.
-        Only optional if hdi_data is present.
+        Only optional if ``hdi_data`` is present.
     hdi_data : array_like, optional
         Precomputed HDI values to use. Assumed shape is ``(*x.shape, 2)``.
     hdi_prob : float, optional
@@ -46,7 +46,7 @@ def plot_hdi(
     color : str, optional
         Color used for the limits of the HDI and fill. Should be a valid matplotlib color.
     circular : bool, optional
-        Whether to compute the HDI taking into account `x` is a circular variable
+        Whether to compute the HDI taking into account ``x`` is a circular variable
         (in the range [-np.pi, np.pi]) or not. Defaults to False (i.e non-circular variables).
     smooth : boolean, optional
         If True the result will be smoothed by first computing a linear interpolation of the data
@@ -59,11 +59,11 @@ def plot_hdi(
         Figure size. If None it will be defined automatically.
     fill_kwargs : dict, optional
         Keywords passed to :meth:`mpl:matplotlib.axes.Axes.fill_between`
-        (use fill_kwargs={'alpha': 0} to disable fill) or to
-        :meth:`bokeh:bokeh.plotting.figure.Figure.patch`.
+        (use ``fill_kwargs={'alpha': 0}`` to disable fill) or to
+        :meth:`bokeh.plotting.Figure.patch`.
     plot_kwargs : dict, optional
         HDI limits keyword arguments, passed to :meth:`mpl:matplotlib.axes.Axes.plot` or
-        :meth:`bokeh:bokeh.plotting.figure.Figure.patch`.
+        :meth:`bokeh.plotting.Figure.patch`.
     hdi_kwargs : dict, optional
         Keyword arguments passed to :func:`~arviz.hdi`. Ignored if ``hdi_data`` is present.
     ax : axes, optional
@@ -71,7 +71,9 @@ def plot_hdi(
     backend : {"matplotlib","bokeh"}, optional
         Select plotting backend.
     backend_kwargs : bool, optional
-        These are kwargs specific to the backend being used. Passed to ::``
+        These are kwargs specific to the backend being used, passed to
+        :meth:`mpl:matplotlib.axes.Axes.plot` or
+        :meth:`bokeh.plotting.Figure.patch`.
     show : bool, optional
         Call backend show function.
 
@@ -93,7 +95,7 @@ def plot_hdi(
         >>> import numpy as np
         >>> import arviz as az
         >>> x_data = np.random.normal(0, 1, 100)
-        >>> y_data = np.random.normal(2 + x_data * 0.5, 0.5, (2, 50, 100))
+        >>> y_data = np.random.normal(2 + x_data * 0.5, 0.5, size=(2, 50, 100))
         >>> az.plot_hdi(x_data, y_data)
 
     ``plot_hdi`` can also be given precalculated values with the argument ``hdi_data``. This example
@@ -109,6 +111,19 @@ def plot_hdi(
         >>> ax = az.plot_hdi(x_data, hdi_data=hdi_data[0], color="r", fill_kwargs={"alpha": .2})
         >>> az.plot_hdi(x_data, hdi_data=hdi_data[1], color="k", ax=ax, fill_kwargs={"alpha": .2})
 
+    ``plot_hdi`` can also be used with Inference Data objects. Here we use the posterior predictive
+    to plot the HDI interval.
+
+    .. plot::
+        :context: close-figs
+
+        >>> X = np.random.normal(0,1,100)
+        >>> Y = np.random.normal(2 + X * 0.5, 0.5, size=(2,10,100))
+        >>> idata = az.from_dict(posterior={"y": Y}, constant_data={"x":X})
+        >>> x_data = idata.constant_data.x
+        >>> y_data = idata.posterior.y
+        >>> az.plot_hdi(x_data, y_data)
+
     """
     if hdi_kwargs is None:
         hdi_kwargs = {}
