@@ -125,7 +125,7 @@ def default_grid(n_items, grid=None, max_cols=4, min_cols=3):  # noqa: D202
 
         if n_items <= max_cols:
             return 1, n_items
-        ideal = in_bounds(round(n_items ** 0.5))
+        ideal = in_bounds(round(n_items**0.5))
 
         for offset in (0, 1, -1, 2, -2):
             cols = in_bounds(ideal + offset)
@@ -595,3 +595,20 @@ def compute_ranks(ary):
     ranks = rankdata(ary, method="average").reshape(ary.shape)
 
     return ranks
+
+
+def _init_kwargs_dict(kwargs):
+    """Initialize kwargs dict.
+
+    If the input is a dictionary, it returns
+    a copy of the dictionary, otherwise it
+    returns an empty dictionary.
+
+    Parameters
+    ----------
+    kwargs : dict or None
+        kwargs dict to initialize
+    """
+    if kwargs is None:
+        return {}
+    return kwargs.copy()
