@@ -3,6 +3,7 @@
 from .density_utils import *
 from .diagnostics import *
 from .stats import *
+from .stats import _calculate_ics
 from .stats_refitting import *
 from .stats_utils import *
 
@@ -11,11 +12,11 @@ __all__ = [
     "bfmi",
     "compare",
     "hdi",
-    "hpd",
     "kde",
     "loo",
     "loo_pit",
     "psislw",
+    "r2_samples",
     "r2_score",
     "summary",
     "waic",
@@ -23,10 +24,10 @@ __all__ = [
     "ess",
     "rhat",
     "mcse",
-    "geweke",
     "autocorr",
     "autocov",
     "make_ufunc",
     "wrap_xarray_ufunc",
     "reloo",
+    "_calculate_ics",
 ]
