@@ -8,8 +8,8 @@ import pytest
 from numpy.testing import assert_almost_equal
 
 from ...data import from_cmdstan, load_arviz_data
-from ...plots.plot_utils import xarray_var_iter
-from ...rcparams import rc_context, rcParams
+from ...rcparams import rcParams
+from ...sel_utils import xarray_var_iter
 from ...stats import bfmi, ess, mcse, rhat
 from ...stats.diagnostics import (
     _ess,
@@ -119,8 +119,7 @@ class TestDiagnostics:
         here = os.path.dirname(os.path.abspath(__file__))
         data_directory = os.path.join(here, "..", "saved_models")
         path = os.path.join(data_directory, "stan_diagnostics", "blocker.[0-9].csv")
-        with rc_context(rc={"data.pandas_float_precision": "high"}):
-            posterior = from_cmdstan(path)
+        posterior = from_cmdstan(path)
         reference_path = os.path.join(data_directory, "stan_diagnostics", "reference_posterior.csv")
         reference = (
             pd.read_csv(reference_path, index_col=0, float_precision="high")
@@ -148,9 +147,9 @@ class TestDiagnostics:
             "mcse_quantile30": lambda x: mcse(x, method="quantile", prob=0.3),
         }
         results = {}
-        for key, coord_dict, vals in xarray_var_iter(posterior.posterior, combined=True):
+        for key, coord_dict, _, vals in xarray_var_iter(posterior.posterior, combined=True):
             if coord_dict:
-                key = key + ".{}".format(list(coord_dict.values())[0] + 1)
+                key = key + f".{list(coord_dict.values())[0] + 1}"
             results[key] = {func_name: func(vals) for func_name, func in funcs.items()}
         arviz_data = pd.DataFrame.from_dict(results).T.sort_index(axis=1).sort_index(axis=0)
 
@@ -303,7 +302,7 @@ class TestDiagnostics:
             else:
                 ess_value = ess(data, method=method, relative=relative)
             assert not np.isnan(ess_value)
-        # test following only once tests are runned
+        # test following only once tests are run
         if (method == "bulk") and (not relative) and (chain is None) and (draw == 4):
             if use_nan:
                 assert np.isnan(_ess(data))
@@ -418,7 +417,7 @@ class TestDiagnostics:
     @pytest.mark.parametrize("draws", (3, 4, 100))
     @pytest.mark.parametrize("chains", (None, 1, 2))
     def test_multichain_summary_array(self, draws, chains):
-        """Test multichain statistics against invidual functions."""
+        """Test multichain statistics against individual functions."""
         if chains is None:
             ary = np.random.randn(draws)
         else:
