@@ -4,6 +4,7 @@ from copy import deepcopy
 import numpy as np
 import pytest
 from numpy.testing import assert_allclose, assert_array_almost_equal, assert_array_equal
+from scipy.special import logsumexp
 from scipy.stats import linregress
 from xarray import DataArray, Dataset
 
@@ -318,19 +319,39 @@ METRICS_NAMES = [
     "ess_bulk",
     "ess_tail",
     "r_hat",
+    "median",
+    "mad",
+    "eti_3%",
+    "eti_97%",
+    "mcse_median",
+    "ess_median",
+    "ess_tail",
+    "r_hat",
 ]
 
 
 @pytest.mark.parametrize(
     "params",
-    (("all", METRICS_NAMES), ("stats", METRICS_NAMES[:4]), ("diagnostics", METRICS_NAMES[4:])),
+    (
+        ("mean", "all", METRICS_NAMES[:9]),
+        ("mean", "stats", METRICS_NAMES[:4]),
+        ("mean", "diagnostics", METRICS_NAMES[4:9]),
+        ("median", "all", METRICS_NAMES[9:17]),
+        ("median", "stats", METRICS_NAMES[9:13]),
+        ("median", "diagnostics", METRICS_NAMES[13:17]),
+    ),
 )
-def test_summary_kind(centered_eight, params):
-    kind, metrics_names_ = params
-    summary_df = summary(centered_eight, kind=kind)
+def test_summary_focus_kind(centered_eight, params):
+    stat_focus, kind, metrics_names_ = params
+    summary_df = summary(centered_eight, stat_focus=stat_focus, kind=kind)
     assert_array_equal(summary_df.columns, metrics_names_)
 
 
+def test_summary_wrong_focus(centered_eight):
+    with pytest.raises(TypeError, match=r"Invalid format: 'WrongFocus'.*"):
+        summary(centered_eight, stat_focus="WrongFocus")
+
+
 @pytest.mark.parametrize("fmt", ["wide", "long", "xarray"])
 def test_summary_fmt(centered_eight, fmt):
     assert summary(centered_eight, fmt=fmt) is not None
@@ -534,6 +555,16 @@ def test_psislw(centered_eight):
     assert_allclose(pareto_k, psislw(-log_likelihood, 0.7)[1])
 
 
+def test_psislw_smooths_for_low_k():
+    # check that log-weights are smoothed even when k < 1/3
+    # https://github.com/arviz-devs/arviz/issues/2010
+    rng = np.random.default_rng(44)
+    x = rng.normal(size=100)
+    x_smoothed, k = psislw(x.copy())
+    assert k < 1 / 3
+    assert not np.allclose(x - logsumexp(x), x_smoothed)
+
+
 @pytest.mark.parametrize("probs", [True, False])
 @pytest.mark.parametrize("kappa", [-1, -0.5, 1e-30, 0.5, 1])
 @pytest.mark.parametrize("sigma", [0, 2])
