@@ -17,6 +17,12 @@ from .rcparams import rcParams
 STATIC_FILES = ("static/html/icons-svg-inline.html", "static/css/style.css")
 
 
+def _check_tilde_start(x):
+    if isinstance(x, str) and x.startswith("~"):
+        return True
+    return False
+
+
 def _var_names(var_names, data, filter_vars=None):
     """Handle var_names input across arviz.
 
@@ -51,7 +57,7 @@ def _var_names(var_names, data, filter_vars=None):
         else:
             all_vars = list(data.data_vars)
 
-        all_vars_tilde = [var for var in all_vars if var.startswith("~")]
+        all_vars_tilde = [var for var in all_vars if _check_tilde_start(var)]
         if all_vars_tilde:
             warnings.warn(
                 """ArviZ treats '~' as a negation character for variable selection.
@@ -95,7 +101,7 @@ def _subset_list(subset, whole_list, filter_items=None, warn=True):
         if isinstance(subset, str):
             subset = [subset]
 
-        whole_list_tilde = [item for item in whole_list if item.startswith("~")]
+        whole_list_tilde = [item for item in whole_list if _check_tilde_start(item)]
         if whole_list_tilde and warn:
             warnings.warn(
                 "ArviZ treats '~' as a negation character for selection. There are "
@@ -106,7 +112,7 @@ def _subset_list(subset, whole_list, filter_items=None, warn=True):
             )
 
         excluded_items = [
-            item[1:] for item in subset if item.startswith("~") and item not in whole_list
+            item[1:] for item in subset if _check_tilde_start(item) and item not in whole_list
         ]
         filter_items = str(filter_items).lower()
         not_found = []
